@@ -19,9 +19,9 @@ import logging
 import os
 import re
 import sys
-import typing
 from collections.abc import Mapping, MutableMapping
 from pathlib import Path
+from typing import Any, Iterable, Iterator
 
 import colour
 import numpy as np
@@ -29,7 +29,6 @@ import numpy as np
 from .. import constants
 from ..utils.tex import TexTemplate, TexTemplateFromFile
 from ..utils.tex_templates import TexTemplateLibrary
-from .logger_utils import set_file_logger
 
 
 def config_file_paths() -> list[Path]:
@@ -255,7 +254,6 @@ class ManimConfig(MutableMapping):
         "input_file",
         "media_embed",
         "media_width",
-        "webgl_renderer_path",
         "log_dir",
         "log_to_file",
         "max_files_cached",
@@ -282,7 +280,6 @@ class ManimConfig(MutableMapping):
         "upto_animation_number",
         "renderer",
         "use_opengl_renderer",
-        "use_webgl_renderer",
         "enable_gui",
         "gui_location",
         "use_projection_fill_shaders",
@@ -304,7 +301,7 @@ class ManimConfig(MutableMapping):
         self._d = {k: None for k in self._OPTS}
 
     # behave like a dict
-    def __iter__(self) -> typing.Iterator[str]:
+    def __iter__(self) -> Iterator[str]:
         return iter(self._d)
 
     def __len__(self) -> int:
@@ -317,10 +314,10 @@ class ManimConfig(MutableMapping):
         except AttributeError:
             return False
 
-    def __getitem__(self, key) -> typing.Any:
+    def __getitem__(self, key) -> Any:
         return getattr(self, key)
 
-    def __setitem__(self, key: str, val: typing.Any) -> None:
+    def __setitem__(self, key: str, val: Any) -> None:
         getattr(ManimConfig, key).fset(self, val)  # fset is the property's setter
 
     def update(self, obj: ManimConfig | dict) -> None:
@@ -395,7 +392,7 @@ class ManimConfig(MutableMapping):
         """See ManimConfig.copy()."""
         return copy.deepcopy(self)
 
-    def __deepcopy__(self, memo: dict[str, typing.Any]) -> ManimConfig:
+    def __deepcopy__(self, memo: dict[str, Any]) -> ManimConfig:
         """See ManimConfig.copy()."""
         c = ManimConfig()
         # Deepcopying the underlying dict is enough because all properties
@@ -405,14 +402,14 @@ class ManimConfig(MutableMapping):
         return c
 
     # helper type-checking methods
-    def _set_from_list(self, key: str, val: typing.Any, values: list) -> None:
+    def _set_from_list(self, key: str, val: Any, values: list) -> None:
         """Set ``key`` to ``val`` if ``val`` is contained in ``values``."""
         if val in values:
             self._d[key] = val
         else:
             raise ValueError(f"attempted to set {key} to {val}; must be in {values}")
 
-    def _set_boolean(self, key: str | int, val: typing.Any) -> None:
+    def _set_boolean(self, key: str | int, val: Any) -> None:
         """Set ``key`` to ``val`` if ``val`` is Boolean."""
         if val in [True, False]:
             self._d[key] = val
@@ -425,7 +422,7 @@ class ManimConfig(MutableMapping):
         else:
             raise ValueError(f"{key} must be tuple")
 
-    def _set_str(self, key: str, val: typing.Any) -> None:
+    def _set_str(self, key: str, val: Any) -> None:
         """Set ``key`` to ``val`` if ``val`` is a string."""
         if isinstance(val, str):
             self._d[key] = val
@@ -537,7 +534,6 @@ class ManimConfig(MutableMapping):
             "flush_cache",
             "custom_folders",
             "use_opengl_renderer",
-            "use_webgl_renderer",
             "enable_gui",
             "fullscreen",
             "use_projection_fill_shaders",
@@ -577,7 +573,6 @@ class ManimConfig(MutableMapping):
             "movie_file_extension",
             "background_color",
             "renderer",
-            "webgl_renderer_path",
             "window_position",
         ]:
             setattr(self, key, parser["CLI"].get(key, fallback="", raw=True))
@@ -710,7 +705,6 @@ class ManimConfig(MutableMapping):
             "renderer",
             "background_color",
             "use_opengl_renderer",
-            "use_webgl_renderer",
             "enable_gui",
             "fullscreen",
             "use_projection_fill_shaders",
@@ -835,8 +829,7 @@ class ManimConfig(MutableMapping):
                 filename,
             )
 
-        if filename:
-            return self.digest_parser(make_config_parser(filename))
+        return self.digest_parser(make_config_parser(filename))
 
     # config options are properties
     preview = property(
@@ -861,19 +854,11 @@ class ManimConfig(MutableMapping):
         doc="Whether to show progress bars while rendering animations.",
     )
 
-    @property
-    def log_to_file(self):
-        """Whether to save logs to a file."""
-        return self._d["log_to_file"]
-
-    @log_to_file.setter
-    def log_to_file(self, val: str) -> None:
-        self._set_boolean("log_to_file", val)
-        if val:
-            log_dir = self.get_dir("log_dir")
-            if not os.path.exists(log_dir):
-                os.makedirs(log_dir)
-            set_file_logger(self, self["verbosity"])
+    log_to_file = property(
+        lambda self: self._d["log_to_file"],
+        lambda self, val: self._set_boolean("log_to_file", val),
+        doc="Whether to save logs to a file.",
+    )
 
     notify_outdated_version = property(
         lambda self: self._d["notify_outdated_version"],
@@ -929,12 +914,6 @@ class ManimConfig(MutableMapping):
         doc="Set to force window when using the opengl renderer",
     )
 
-    dry_run = property(
-        lambda self: self._d["dry_run"],
-        lambda self, val: self._set_boolean("dry_run", val),
-        doc="Enable dry_run so that no output files are generated and window is disabled.",
-    )
-
     @property
     def verbosity(self):
         """Logger verbosity; "DEBUG", "INFO", "WARNING", "ERROR", or "CRITICAL" (-v)."""
@@ -1181,7 +1160,7 @@ class ManimConfig(MutableMapping):
 
     @property
     def renderer(self):
-        """Renderer: "cairo", "opengl", "webgl"""
+        """Renderer: "cairo", "opengl"""
         return self._d["renderer"]
 
     @renderer.setter
@@ -1221,7 +1200,7 @@ class ManimConfig(MutableMapping):
         self._set_from_list(
             "renderer",
             val,
-            ["cairo", "opengl", "webgl"],
+            ["cairo", "opengl"],
         )
 
     @property
@@ -1236,31 +1215,9 @@ class ManimConfig(MutableMapping):
             self._set_from_list(
                 "renderer",
                 "opengl",
-                ["cairo", "opengl", "webgl"],
+                ["cairo", "opengl"],
             )
 
-    @property
-    def use_webgl_renderer(self):
-        """Whether or not to use WebGL renderer."""
-        return self._d["use_webgl_renderer"]
-
-    @use_webgl_renderer.setter
-    def use_webgl_renderer(self, val: bool) -> None:
-        self._d["use_webgl_renderer"] = val
-        if val:
-            self._set_from_list(
-                "webgl",
-                "renderer",
-                ["cairo", "opengl", "webgl"],
-            )
-            self["disable_caching"] = True
-
-    webgl_renderer_path = property(
-        lambda self: self._d["webgl_renderer_path"],
-        lambda self, val: self._d.__setitem__("webgl_renderer_path", val),
-        doc="Path to WebGL renderer.",
-    )
-
     media_dir = property(
         lambda self: self._d["media_dir"],
         lambda self, val: self._set_dir("media_dir", val),
@@ -1637,7 +1594,7 @@ class ManimFrame(Mapping):
         self.__dict__["_c"] = c
 
     # there are required by parent class Mapping to behave like a dict
-    def __getitem__(self, key: str | int) -> typing.Any:
+    def __getitem__(self, key: str | int) -> Any:
         if key in self._OPTS:
             return self._c[key]
         elif key in self._CONSTANTS:
@@ -1645,7 +1602,7 @@ class ManimFrame(Mapping):
         else:
             raise KeyError(key)
 
-    def __iter__(self) -> typing.Iterable:
+    def __iter__(self) -> Iterable:
         return iter(list(self._OPTS) + list(self._CONSTANTS))
 
     def __len__(self) -> int:
