@@ -26,6 +26,7 @@ from .render_options import render_options
 
 @cloup.command(
     context_settings=None,
+    no_args_is_help=True,
     epilog=EPILOG,
 )
 @click.argument("file", type=Path, required=True)
@@ -50,16 +51,6 @@ def render(
         )
         args["renderer"] = "opengl"
 
-    if args["use_webgl_renderer"]:
-        logger.warning(
-            "--use_webgl_renderer is deprecated, please use --renderer=webgl instead!",
-        )
-        args["renderer"] = "webgl"
-
-    if args["use_webgl_renderer"] and args["use_opengl_renderer"]:
-        logger.warning("You may select only one renderer!")
-        sys.exit()
-
     if args["save_as_gif"]:
         logger.warning("--save_as_gif is deprecated, please use --format=gif instead!")
         args["format"] = "gif"
@@ -120,20 +111,6 @@ def render(
         except Exception:
             error_console.print_exception()
             sys.exit(1)
-    elif config.renderer == "webgl":
-        try:
-            from manim.grpc.impl import frame_server_impl
-
-            server = frame_server_impl.get(file)
-            server.start()
-            server.wait_for_termination()
-        except ModuleNotFoundError:
-            console.print(
-                "Dependencies for the WebGL render are missing. Run "
-                "pip install manim[webgl_renderer] to install them.",
-            )
-            error_console.print_exception()
-            sys.exit(1)
     else:
         for SceneClass in scene_classes_from_file(file):
             try:
