@@ -5,6 +5,7 @@ Constant definitions.
 from __future__ import annotations
 
 import numpy as np
+from cloup import Context
 from PIL import Image
 
 __all__ = [
@@ -67,12 +68,10 @@ __all__ = [
     "GIF_FILE_EXTENSION",
     "FFMPEG_VERBOSITY_MAP",
     "VERBOSITY_CHOICES",
-    "WEBGL_RENDERER_INFO",
     "QUALITIES",
     "DEFAULT_QUALITY",
     "DEFAULT_QUALITY_SHORT",
     "EPILOG",
-    "HELP_OPTIONS",
     "CONTEXT_SETTINGS",
     "SHIFT_VALUE",
     "CTRL_VALUE",
@@ -216,12 +215,6 @@ FFMPEG_VERBOSITY_MAP: dict[str, str] = {
     "CRITICAL": "fatal",
 }
 VERBOSITY_CHOICES = FFMPEG_VERBOSITY_MAP.keys()
-WEBGL_RENDERER_INFO: str = (
-    "The Electron frontend to Manim is hosted at "
-    "https://github.com/ManimCommunity/manim-renderer. After cloning and building it, "
-    "you can either start it prior to running Manim or specify the path to the "
-    "executable with the --webgl_renderer_path flag."
-)
 
 # Video qualities
 QUALITIES: dict[str, dict[str, str | int | None]] = {
@@ -267,7 +260,11 @@ DEFAULT_QUALITY: str = "high_quality"
 DEFAULT_QUALITY_SHORT = QUALITIES[DEFAULT_QUALITY]["flag"]
 
 EPILOG = "Made with <3 by Manim Community developers."
-HELP_OPTIONS = ["-h", "--help"]
-CONTEXT_SETTINGS = {"help_option_names": HELP_OPTIONS}
 SHIFT_VALUE = 65505
 CTRL_VALUE = 65507
+
+CONTEXT_SETTINGS = Context.settings(
+    align_option_groups=True,
+    align_sections=True,
+    show_constraints=True,
+)
