@@ -19,6 +19,7 @@ from pydub import AudioSegment
 from manim import __version__
 
 from .. import config, logger
+from .._config.logger_utils import set_file_logger
 from ..constants import FFMPEG_BIN, GIF_FILE_EXTENSION
 from ..utils.file_ops import (
     add_extension_if_not_present,
@@ -110,9 +111,8 @@ class SceneFileWriter:
                     "images_dir", module_name=module_name, scene_name=scene_name
                 ),
             )
-            self.image_file_path = os.path.join(
-                image_dir,
-                add_extension_if_not_present(self.output_name, ".png"),
+            self.image_file_path = image_dir / add_extension_if_not_present(
+                self.output_name, ".png"
             )
 
         if write_to_movie():
@@ -121,14 +121,10 @@ class SceneFileWriter:
                     "video_dir", module_name=module_name, scene_name=scene_name
                 ),
             )
-
-            self.movie_file_path = os.path.join(
-                movie_dir,
-                add_extension_if_not_present(
-                    self.output_name,
-                    config["movie_file_extension"],
-                ),
+            self.movie_file_path = movie_dir / add_extension_if_not_present(
+                self.output_name, config["movie_file_extension"]
             )
+
             # TODO: /dev/null would be good in case sections_output_dir is used without bein set (doesn't work on Windows), everyone likes defensive programming, right?
             self.sections_output_dir = ""
             if config.save_sections:
@@ -148,7 +144,7 @@ class SceneFileWriter:
                         self.gif_file_path
                     )
 
-                self.gif_file_path = os.path.join(movie_dir, self.gif_file_path)
+                self.gif_file_path = movie_dir / self.gif_file_path
 
             self.partial_movie_directory = guarantee_existence(
                 config.get_dir(
@@ -158,6 +154,12 @@ class SceneFileWriter:
                 ),
             )
 
+            if config["log_to_file"]:
+                log_dir = guarantee_existence(config.get_dir("log_dir"))
+                set_file_logger(
+                    scene_name=scene_name, module_name=module_name, log_dir=log_dir
+                )
+
     def finish_last_section(self) -> None:
         """Delete current section if it is empty."""
         if len(self.sections) and self.sections[-1].is_empty():
@@ -206,9 +208,9 @@ class SceneFileWriter:
             self.partial_movie_files.append(None)
             self.sections[-1].partial_movie_files.append(None)
         else:
-            new_partial_movie_file = os.path.join(
-                self.partial_movie_directory,
-                f"{hash_animation}{config['movie_file_extension']}",
+            new_partial_movie_file = str(
+                self.partial_movie_directory
+                / f"{hash_animation}{config['movie_file_extension']}"
             )
             self.partial_movie_files.append(new_partial_movie_file)
             self.sections[-1].partial_movie_files.append(new_partial_movie_file)
@@ -373,7 +375,8 @@ class SceneFileWriter:
                 renderer.get_raw_frame_buffer_object_data(),
             )
         elif is_png_format() and not config["dry_run"]:
-            target_dir, extension = os.path.splitext(self.image_file_path)
+            target_dir = self.image_file_path.parent / self.image_file_path.stem
+            extension = self.image_file_path.suffix
             self.output_image(
                 renderer.get_image(),
                 target_dir,
@@ -382,7 +385,8 @@ class SceneFileWriter:
             )
 
     def output_image_from_array(self, frame_data):
-        target_dir, extension = os.path.splitext(self.image_file_path)
+        target_dir = self.image_file_path.parent / self.image_file_path.stem
+        extension = self.image_file_path.suffix
         self.output_image(
             Image.fromarray(frame_data),
             target_dir,
@@ -435,8 +439,8 @@ class SceneFileWriter:
             else:
                 self.clean_cache()
         elif is_png_format() and not config["dry_run"]:
-            target_dir, _ = os.path.splitext(self.image_file_path)
-            logger.info("\n%i images ready at %s\n", self.frame_count, target_dir)
+            target_dir = self.image_file_path.parent / self.image_file_path.stem
+            logger.info("\n%i images ready at %s\n", self.frame_count, str(target_dir))
         if self.subcaptions:
             self.write_subcaption_file()
 
@@ -517,11 +521,11 @@ class SceneFileWriter:
         """
         if not hasattr(self, "partial_movie_directory") or not write_to_movie():
             return False
-        path = os.path.join(
-            self.partial_movie_directory,
-            f"{hash_invocation}{config['movie_file_extension']}",
+        path = (
+            self.partial_movie_directory
+            / f"{hash_invocation}{config['movie_file_extension']}"
         )
-        return os.path.exists(path)
+        return path.exists()
 
     def combine_files(
         self,
@@ -530,10 +534,7 @@ class SceneFileWriter:
         create_gif=False,
         includes_sound=False,
     ):
-        file_list = os.path.join(
-            self.partial_movie_directory,
-            "partial_movie_file_list.txt",
-        )
+        file_list = str(self.partial_movie_directory / "partial_movie_file_list.txt")
         logger.debug(
             f"Partial movie files to combine ({len(input_files)} files): %(p)s",
             {"p": input_files[:5]},
@@ -541,6 +542,7 @@ class SceneFileWriter:
         with open(file_list, "w", encoding="utf-8") as fp:
             fp.write("# This file is used internally by FFMPEG.\n")
             for pf_path in input_files:
+                pf_path = str(pf_path)
                 if os.name == "nt":
                     pf_path = pf_path.replace("\\", "/")
                 fp.write(f"file 'file:{pf_path}'\n")
@@ -571,7 +573,7 @@ class SceneFileWriter:
         if not includes_sound:
             commands += ["-an"]
 
-        commands += [output_file]
+        commands += [str(output_file)]
 
         combine_process = subprocess.Popen(commands)
         combine_process.wait()
@@ -591,6 +593,7 @@ class SceneFileWriter:
         movie_file_path = self.movie_file_path
         if is_gif_format():
             movie_file_path = self.gif_file_path
+        movie_file_path = str(movie_file_path)
         logger.info("Combining to Movie file.")
         self.combine_files(
             partial_movie_files,
@@ -668,8 +671,8 @@ class SceneFileWriter:
     def clean_cache(self):
         """Will clean the cache by removing the oldest partial_movie_files."""
         cached_partial_movies = [
-            os.path.join(self.partial_movie_directory, file_name)
-            for file_name in os.listdir(self.partial_movie_directory)
+            (self.partial_movie_directory / file_name)
+            for file_name in self.partial_movie_directory.iterdir()
             if file_name != "partial_movie_file_list.txt"
         ]
         if len(cached_partial_movies) > config["max_files_cached"]:
@@ -682,7 +685,7 @@ class SceneFileWriter:
             )[:number_files_to_delete]
             # oldest_file_path = min(cached_partial_movies, key=os.path.getatime)
             for file_to_delete in oldest_files_to_delete:
-                os.remove(file_to_delete)
+                file_to_delete.unlink()
             logger.info(
                 f"The partial movie directory is full (> {config['max_files_cached']} files). Therefore, manim has removed the {number_files_to_delete} oldest file(s)."
                 " You can change this behaviour by changing max_files_cached in config.",
@@ -691,12 +694,12 @@ class SceneFileWriter:
     def flush_cache_directory(self):
         """Delete all the cached partial movie files"""
         cached_partial_movies = [
-            os.path.join(self.partial_movie_directory, file_name)
-            for file_name in os.listdir(self.partial_movie_directory)
+            self.partial_movie_directory / file_name
+            for file_name in self.partial_movie_directory.iterdir()
             if file_name != "partial_movie_file_list.txt"
         ]
         for f in cached_partial_movies:
-            os.remove(f)
+            f.unlink()
         logger.info(
             f"Cache flushed. {len(cached_partial_movies)} file(s) deleted in %(par_dir)s.",
             {"par_dir": self.partial_movie_directory},
