@@ -73,6 +73,8 @@ directive:
         that is rendered in a reference block after the source code.
 
 """
+from __future__ import annotations
+
 import csv
 import itertools as it
 import os
@@ -81,7 +83,6 @@ import shutil
 import sys
 from pathlib import Path
 from timeit import timeit
-from typing import Callable, List
 
 import jinja2
 from docutils import nodes
@@ -105,7 +106,7 @@ def depart(self, node):
     self.depart_admonition(node)
 
 
-def process_name_list(option_input: str, reference_type: str) -> List[str]:
+def process_name_list(option_input: str, reference_type: str) -> list[str]:
     r"""Reformats a string of space separated class names
     as a list of strings containing valid Sphinx references.
 
@@ -341,8 +342,6 @@ def _delete_rendering_times(*args):
 
 
 def setup(app):
-    import manim
-
     app.add_node(skip_manim_node, html=(visit, depart))
 
     setup.app = app
