@@ -84,7 +84,10 @@ def generate_tex_file(expression, environment=None, tex_template=None):
 
     result = os.path.join(tex_dir, tex_hash(output)) + ".tex"
     if not os.path.exists(result):
-        logger.info(f"Writing {expression} to %(path)s", {"path": f"{result}"})
+        logger.info(
+            "Writing %(expression)s to %(path)s",
+            {"expression": expression, "path": f"{result}"},
+        )
         with open(result, "w", encoding="utf-8") as outfile:
             outfile.write(output)
     return result
